
.. py:currentmodule:: pythreejs

PolarGridHelper
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: PolarGridHelper(radius=10, radials=16, circles=8, divisions=64, color1="0x444444", color2="0x888888", )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.Object3D`.

    Three.js docs: https://threejs.org/docs/#api/helpers/PolarGridHelper


    .. py:attribute:: radius

        .. sourcecode:: python

            CInt(10, allow_none=False).tag(sync=True)

    .. py:attribute:: radials

        .. sourcecode:: python

            CInt(16, allow_none=False).tag(sync=True)

    .. py:attribute:: circles

        .. sourcecode:: python

            CInt(8, allow_none=False).tag(sync=True)

    .. py:attribute:: divisions

        .. sourcecode:: python

            CInt(64, allow_none=False).tag(sync=True)

    .. py:attribute:: color1

        .. sourcecode:: python

            Unicode("0x444444", allow_none=False).tag(sync=True)

    .. py:attribute:: color2

        .. sourcecode:: python

            Unicode("0x888888", allow_none=False).tag(sync=True)

